@@ -2,11 +2,12 @@
 Create torrent file
 """
 
+import fnmatch
 import os
 import queue
 
 from .. import errors
-from ..utils import btclients, daemon, fs, torrent
+from ..utils import btclients, daemon, fs, is_regex_pattern, torrent
 from . import base
 
 import logging  # isort:skip
@@ -21,28 +22,40 @@ class CreateTorrentJob(base.JobBase):
     attribute:
 
         ``announce_url``
-
             Emitted before and after successful announce URL retrieval.
             Registered callbacks get an :class:`Ellipsis` to indicate the
             retrieval attempt and the announce URL if the attempt was
             successful.
 
+        ``file_tree``
+            Emitted when torrent creation begins. Registered callbacks get
+            nested `(file_name, file_size)` tuples (see
+            :func:`~.utils.torrent.create`) as a positional argument. (See also
+            :func:`.fs.format_file_tree`.)
+
         ``progress_update``
-            Emitted in roughly equal intervals to provide torrent creation
-            progress. Registered callbacks get a `float` between 0.0 and 100.0
-            as a positional argument.
+            Emitted at roughly equal intervals to provide information about the
+            torrent creation progress. Registered callbacks get a
+            :class:`~.torrent.CreateTorrentStatus` instance as a positional
+            argument.
     """
 
     name = 'torrent'
     label = 'Torrent'
     cache_id = None
 
-    def initialize(self, *, tracker, content_path):
+    def initialize(self, *, tracker, content_path, exclude_files=()):
         """
         Set internal state
 
         :param TrackerBase tracker: Return value of :func:`.trackers.tracker`
         :param content_path: Path to file or directory
+        :param exclude_files: Sequence of glob patterns (:class:`str`) and
+            :class:`re.Pattern` objects that are matched against the relative
+            path within the generated torrent
+
+            .. note:: This sequence is added to the ``exclude`` list in
+               :class:`~.base.TrackerConfigBase`.
         """
         self._tracker = tracker
         self._content_path = content_path
@@ -50,8 +63,16 @@ class CreateTorrentJob(base.JobBase):
             self.home_directory,
             f'{fs.basename(content_path)}.{tracker.name.lower()}.torrent',
         )
-        self.signal.add('progress_update')
+
+        self._exclude_files = list(self._tracker.options['exclude'])
+        for pattern in exclude_files:
+            if not is_regex_pattern(pattern):
+                pattern = fnmatch.translate(str(pattern))
+            self._exclude_files.append(pattern)
+
         self.signal.add('announce_url')
+        self.signal.add('file_tree')
+        self.signal.add('progress_update')
         self._torrent_process = None
 
     def execute(self):
@@ -92,7 +113,7 @@ class CreateTorrentJob(base.JobBase):
                 'overwrite'    : self.ignore_cache,
                 'announce'     : announce_url,
                 'source'       : self._tracker.options['source'],
-                'exclude'      : self._tracker.options['exclude'],
+                'exclude'      : self._exclude_files,
             },
             init_callback=self._handle_file_tree,
             info_callback=self._handle_progress_update,
@@ -109,10 +130,10 @@ class CreateTorrentJob(base.JobBase):
         super().finish()
 
     def _handle_file_tree(self, file_tree):
-        self.info = fs.file_tree(file_tree)
+        self.signal.emit('file_tree', file_tree)
 
-    def _handle_progress_update(self, percent_done):
-        self.signal.emit('progress_update', percent_done)
+    def _handle_progress_update(self, status):
+        self.signal.emit('progress_update', status)
 
     def _handle_torrent_created(self, torrent_path=None):
         _log.debug('Torrent created: %r', torrent_path)
@@ -279,10 +300,7 @@ class CopyTorrentJob(base.QueueJobBase):
             try:
                 new_path = shutil.copy2(filepath, self._destination)
             except OSError as e:
-                if e.strerror:
-                    msg = e.strerror
-                else:
-                    msg = str(e)
+                msg = e.strerror if e.strerror else str(e)
                 self.error(f'Failed to copy {filepath} to {self._destination}: {msg}')
                 # Default to original torrent path
                 self.send(filepath)
