@@ -7,7 +7,7 @@ import collections
 from time import monotonic as time_monotonic
 
 from .. import errors
-from ..utils import fs, webdbs
+from ..utils import webdbs
 from . import JobBase
 
 import logging  # isort:skip
@@ -44,6 +44,10 @@ class WebDbSearchJob(JobBase):
             :class:`~.utils.webdbs.common.SearchResult` object that returns a
             coroutine function. ``value`` is the return value of that coroutine
             function.
+
+        ``query_updated``
+            Emitted after the :attr:`query` changed. Registered callbacks get
+            the new query as a positional argument.
     """
 
     @property
@@ -56,33 +60,36 @@ class WebDbSearchJob(JobBase):
 
     @property
     def cache_id(self):
-        """Final segment of `content_path` and database :attr:`~.WebDbApiBase.name`"""
-        return fs.basename(self._content_path)
+        """Database :attr:`~.WebDbApiBase.name` and :attr:`query`"""
+        return (self._db.name, self.query)
 
     @property
     def query(self):
         """:class:`~.webdbs.common.Query` instance"""
         return self._query
 
-    def initialize(self, *, db, content_path):
+    def initialize(self, *, db, query):
         """
         Set internal state
 
         :param WebDbApiBase db: Return value of :func:`.utils.webdbs.webdb`
-        :param str content_path: Path or name of the release (doesn't have to
-            exist)
+        :param query: Path of the release (doesn't have to exist) or
+            :class:`~.webdbs.common.Query` instance
         """
         assert isinstance(db, webdbs.WebDbApiBase), f'Not a WebDbApiBase: {db!r}'
         self._db = db
-        self._content_path = content_path
-        self._query = self._db.sanitize_query(webdbs.Query.from_path(content_path))
-        self._is_searching = False
+        if not isinstance(query, webdbs.Query):
+            query = webdbs.Query.from_path(str(query))
+        self._query = self._db.sanitize_query(query)
+        self._query.signal.register('changed', self._handle_query_changed)
 
         self.signal.add('search_results')
         self.signal.add('searching_status')
         self.signal.add('info_updating')
         self.signal.add('info_updated')
+        self.signal.add('query_updated')
 
+        self._is_searching = False
         self._searcher = _Searcher(
             search_coro=self._db.search,
             results_callback=self._handle_search_results,
@@ -118,7 +125,7 @@ class WebDbSearchJob(JobBase):
         """Search for initial query"""
         # It is important NOT to do this in initialize() because the window
         # between initialize() and execute() is used to register callbacks.
-        self.search(self._query)
+        self.search(self.query)
 
     async def wait(self):
         """Wait for any running internal coroutines"""
@@ -135,13 +142,26 @@ class WebDbSearchJob(JobBase):
         self._info_updater.cancel()
         super().finish()
 
-    def search(self, query):
-        """Make a new search request after cancelling any currently ongoing request"""
+    def search(self, query_string):
+        """
+        Make new search request
+
+        Any currently ongoing search is cancelled.
+
+        :param str query_string: Query string that is first passed through
+            :meth:`~.webdbs.Query.from_string` and then
+            :meth:`~.webdbs.WebDbApiBase.sanitize_query`
+        """
         if not self.is_finished:
-            self._query = self._db.sanitize_query(webdbs.Query.from_string(query))
-            self._searcher.search(self._query)
+            new_query = self._db.sanitize_query(webdbs.Query.from_string(query_string))
+            self.query.update(new_query)
+            self._searcher.search(self.query)
             self.clear_warnings()
 
+    def _handle_query_changed(self, new_query):
+        self.signal.emit('query_updated', new_query)
+        self.search(new_query)
+
     def _handle_searching_status(self, is_searching):
         self._is_searching = bool(is_searching)
         self.signal.emit('searching_status', self._is_searching)
