@@ -24,7 +24,7 @@ class TrackerConfigBase(dict):
         'source'     : '',
         'exclude'    : [],
         'add-to'     : types.Choice(
-            '',
+            value='',
             empty_ok=True,
             options=(client.name for client in btclients.clients()),
         ),
@@ -96,13 +96,14 @@ class TrackerJobsBase(abc.ABC):
     """
 
     def __init__(self, *, content_path, tracker, torrent_destination=None,
-                 options=None, image_host=None, bittorrent_client=None,
-                 common_job_args=None):
+                 exclude_files=(), options=None, image_host=None,
+                 bittorrent_client=None, common_job_args=None):
         self._content_path = content_path
         self._tracker = tracker
         self._image_host = image_host
         self._bittorrent_client = bittorrent_client
         self._torrent_destination = torrent_destination
+        self._exclude_files = exclude_files
         self._common_job_args = common_job_args or {}
         self._options = options or {}
         self._signal = signal.Signal('warning', 'error', 'exception')
@@ -135,6 +136,17 @@ class TrackerJobsBase(abc.ABC):
         """
         return self._torrent_destination
 
+    @property
+    def exclude_files(self):
+        """
+        Sequence of glob and regular expression patterns to exclude from the
+        generated torrent
+
+        See the ``exclude_files`` argument of
+        :meth:`.CreateTorrentJob.initialize`.
+        """
+        return self._exclude_files
+
     @property
     def options(self):
         """
@@ -254,6 +266,21 @@ class TrackerJobsBase(abc.ABC):
         """
         self.signal.emit('exception', exception)
 
+    @cached_property
+    def imdb(self):
+        """:class:`~.webdbs.imdb.ImdbApi` instance"""
+        return webdbs.webdb('imdb')
+
+    @cached_property
+    def tmdb(self):
+        """:class:`~.webdbs.tmdb.TmdbApi` instance"""
+        return webdbs.webdb('tmdb')
+
+    @cached_property
+    def tvmaze(self):
+        """:class:`~.webdbs.tvmaze.TvmazeApi` instance"""
+        return webdbs.webdb('tvmaze')
+
     def get_job_name(self, name):
         """
         Return job name that is unique for this tracker
@@ -278,6 +305,7 @@ class TrackerJobsBase(abc.ABC):
         return jobs.torrent.CreateTorrentJob(
             content_path=self.content_path,
             tracker=self.tracker,
+            exclude_files=self._exclude_files,
             **self.common_job_args,
         )
 
@@ -362,8 +390,8 @@ class TrackerJobsBase(abc.ABC):
     def imdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         imdb_job = jobs.webdb.WebDbSearchJob(
-            content_path=self.content_path,
-            db=webdbs.webdb('imdb'),
+            query=self.content_path,
+            db=self.imdb,
             **self.common_job_args,
         )
         # Update release name with IMDb data
@@ -374,8 +402,8 @@ class TrackerJobsBase(abc.ABC):
     def tmdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
-            content_path=self.content_path,
-            db=webdbs.webdb('tmdb'),
+            query=self.content_path,
+            db=self.tmdb,
             **self.common_job_args,
         )
 
@@ -383,8 +411,8 @@ class TrackerJobsBase(abc.ABC):
     def tvmaze_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
-            content_path=self.content_path,
-            db=webdbs.webdb('tvmaze'),
+            query=self.content_path,
+            db=self.tvmaze,
             **self.common_job_args,
         )
 
@@ -454,7 +482,7 @@ class TrackerJobsBase(abc.ABC):
         )
 
     def make_choice_job(self, name, label, options, condition=None,
-                        autodetected=None, autofinish=False):
+                        callbacks=None, autodetected=None, autofinish=False):
         """
         Return :class:`~.jobs.dialog.ChoiceJob` instance
 
@@ -477,6 +505,7 @@ class TrackerJobsBase(abc.ABC):
               this option is autofocused
 
         :param condition: See :attr:`~.base.JobBase.condition`
+        :param callbacks: See :attr:`~.base.JobBase`
         :param bool autofinish: Whether to choose the autodetected value with no
             user-interaction
         """
@@ -504,6 +533,7 @@ class TrackerJobsBase(abc.ABC):
             name=self.get_job_name(name),
             label=label,
             condition=condition,
+            callbacks=callbacks or {},
             choices=choices,
             focused=focused,
             **self.common_job_args,
