@@ -9,8 +9,7 @@ import re
 import unidecode
 
 from ... import __homepage__, __project_name__, __version__, errors, jobs
-from ...utils import (cached_property, fs, http, image, release, string, video,
-                      webdbs)
+from ...utils import cached_property, fs, http, image, release, string, video
 from ..base import TrackerJobsBase
 
 import logging  # isort:skip
@@ -67,16 +66,6 @@ class BbTrackerJobs(TrackerJobsBase):
 
     # Web DBs
 
-    @cached_property
-    def imdb(self):
-        """:class:`~.webdbs.imdb.ImdbApi` instance"""
-        return webdbs.webdb('imdb')
-
-    @cached_property
-    def tvmaze(self):
-        """:class:`~.webdbs.imdb.TvmazeApi` instance"""
-        return webdbs.webdb('tvmaze')
-
     async def get_imdb_id(self):
         """Return IMDb ID by any means possible, default to `None`"""
         if self.imdb_job.is_enabled:
@@ -126,10 +115,9 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def jobs_before_upload(self):
-        # Turn generic jobs from parent class into conditional jobs. Do not make
-        # all generic jobs conditional; e.g. scene_check_job should always run.
+        # Turn generic jobs from parent class into conditional jobs.
         all_release_types = (release.ReleaseType.movie, release.ReleaseType.series, release.ReleaseType.episode)
-        generic_job_attributes = ('mediainfo_job', 'create_torrent_job',
+        generic_job_attributes = ('mediainfo_job', 'scene_check_job', 'create_torrent_job',
                                   'screenshots_job', 'upload_screenshots_job',
                                   'add_torrent_job', 'copy_torrent_job')
         for job_attr in generic_job_attributes:
@@ -233,9 +221,16 @@ class BbTrackerJobs(TrackerJobsBase):
                 ('Episode', release.ReleaseType.episode),
             ),
             focused=self.release_name.type,
+            callbacks={
+                'output': self.handle_release_type_selected,
+            },
             **self.common_job_args,
         )
 
+    def handle_release_type_selected(self, _):
+        if self.release_type_job.choice:
+            self.imdb_job.query.type = self.release_type_job.choice
+
     # Movie jobs
 
     @cached_property
@@ -243,7 +238,7 @@ class BbTrackerJobs(TrackerJobsBase):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
             condition=self.make_job_condition('imdb_job', release.ReleaseType.movie),
-            content_path=self.content_path,
+            query=self.content_path,
             db=self.imdb,
             **self.common_job_args,
         )
@@ -508,7 +503,7 @@ class BbTrackerJobs(TrackerJobsBase):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
         return jobs.webdb.WebDbSearchJob(
             condition=self.make_job_condition('tvmaze_job', release.ReleaseType.season, release.ReleaseType.episode),
-            content_path=self.content_path,
+            query=self.content_path,
             db=self.tvmaze,
             **self.common_job_args,
         )
