@@ -74,6 +74,16 @@ class BhdTrackerJobs(TrackerJobsBase):
 
         return condition
 
+    @cached_property
+    def imdb_job(self):
+        imdb_job = super().imdb_job
+        imdb_job.signal.register('output', self.handle_imdb_job_output)
+        return imdb_job
+
+    def handle_imdb_job_output(self, _):
+        user_confirmed_type = self.imdb_job.query.type
+        self.tmdb_job.query.type = user_confirmed_type
+
     @cached_property
     def category_job(self):
         # 'output' signal is only emitted when job succeeds while 'finished'
@@ -117,7 +127,6 @@ class BhdTrackerJobs(TrackerJobsBase):
             name=self.get_job_name('type'),
             label='Type',
             condition=self.make_job_condition('type_job'),
-            autofinish=False,
             options=(
                 {'label': 'UHD 100', 'value': 'UHD 100'},
                 {'label': 'UHD 66', 'value': 'UHD 66'},
@@ -165,6 +174,8 @@ class BhdTrackerJobs(TrackerJobsBase):
                 value = self.type_job.focused[1]
                 # Mark autodetected choice
                 self.type_job.set_label(value, f'{label} (autodetected)')
+                # Select autodetected choice (i.e. finish job and don't prompt user)
+                self.type_job.choice = value
                 break
         else:
             self.type_job.focused = 'Other'
@@ -207,7 +218,7 @@ class BhdTrackerJobs(TrackerJobsBase):
                 value = self.source_job.focused[1]
                 # Mark autodetected choice
                 self.source_job.set_label(value, f'{label} (autodetected)')
-                # Select autodetected choice (i.e. finish job)
+                # Select autodetected choice (i.e. finish job and don't prompt user)
                 self.source_job.choice = value
                 break
 
