@@ -22,6 +22,21 @@ class submit(CommandBase):
                     'type': utils.argtypes.content,
                     'help': 'Path to release content',
                 },
+                ('--exclude-files', '--ef'): {
+                    'nargs': '+',
+                    'metavar': 'PATTERN',
+                    'help': ('Glob pattern to exclude from torrent '
+                             '(matched case-sensitively against path in torrent)'),
+                    'default': (),
+                },
+                ('--exclude-files-regex', '--efr'): {
+                    'nargs': '+',
+                    'metavar': 'PATTERN',
+                    'help': ('Regular expression to exclude from torrent '
+                             '(matched case-sensitively against path in torrent)'),
+                    'type': utils.argtypes.regex,
+                    'default': (),
+                },
                 ('--add-to', '-a'): {
                     'type': utils.argtypes.client,
                     'metavar': 'CLIENT',
@@ -33,8 +48,8 @@ class submit(CommandBase):
                     'help': 'Copy the created torrent to PATH (file or directory)',
                 },
             },
-            # Custom arguments defined by tracker
-            **tracker.TrackerConfig.argument_definitions,
+            # Custom arguments defined by tracker for this command
+            **tracker.TrackerConfig.argument_definitions.get('submit', {}),
         }
         for tracker in trackers.trackers()
     }
@@ -92,6 +107,10 @@ class submit(CommandBase):
             image_host=self._get_imghost(),
             bittorrent_client=self._get_btclient(),
             torrent_destination=self._get_torrent_destination(),
+            exclude_files=(
+                tuple(self.args.exclude_files)
+                + tuple(self.args.exclude_files_regex)
+            ),
             common_job_args={
                 'home_directory': self.home_directory,
                 'cache_directory': self.cache_directory,
