@@ -18,6 +18,7 @@ def main(args=None):
 def _main(args=None):
     aioloop = asyncio.get_event_loop()
     get_newer_version_task = None
+    cmd = None
 
     try:
         if utils.is_tty():
@@ -32,7 +33,6 @@ def _main(args=None):
         cmd = commands.run(args)
         application_setup(cmd.config)
         exit_code = ui.run(cmd.jobs_active)
-        application_shutdown(cmd.config)
 
     # UI was terminated by user prematurely
     except errors.CancelledError as e:
@@ -85,3 +85,8 @@ def _main(args=None):
                     print(msg, file=sys.stderr)
 
         return exit_code
+
+    finally:
+        if cmd is not None:
+            # Cleanup cache, close HTTP session, etc.
+            application_shutdown(cmd.config)
