@@ -7,6 +7,7 @@ import importlib
 import inspect
 import itertools
 import os
+import sys
 import types as _types
 
 
@@ -325,6 +326,19 @@ def as_groups(sequence, group_sizes, default=None):
     yield from itertools.zip_longest(*args, fillvalue=default)
 
 
+def is_regex_pattern(object):
+    if sys.version_info >= (3, 7, 0):
+        # This is not properly document but works for now.
+        import re
+        return isinstance(object, re.Pattern)
+    else:
+        # For Python 3.6, use typing.Pattern. This is deprecated and won't exist
+        # in Python 3.12 anymore.
+        # https://docs.python.org/3/library/typing.html#typing.Pattern
+        import typing
+        return isinstance(object, typing.Pattern)
+
+
 from . import (argtypes, browser, btclients, configfiles, daemon, fs, html,
                http, image, imghosts, iso, release, scene, signal, string,
                subproc, timestamp, torrent, types, update, video, webdbs)
