@@ -3,6 +3,7 @@ Base class for image uploaders
 """
 
 import abc
+import collections
 import copy
 import json
 import os
@@ -21,14 +22,16 @@ class ImageHostBase(abc.ABC):
 
     :param str cache_directory: Where to store URLs in JSON files; defaults to
         :attr:`.constants.CACHE_DIRPATH`
-    :param dict config: User configuration
+    :param options: User configuration options for this image host,
+        e.g. authentication details, thumbnail size, etc
+    :type options: :class:`dict`-like
     """
 
-    def __init__(self, cache_directory=None, config=None):
+    def __init__(self, cache_directory=None, options=None):
+        self._options = copy.deepcopy(self.default_config)
+        if options is not None:
+            self._options.update(options)
         self.cache_directory = cache_directory if cache_directory else constants.CACHE_DIRPATH
-        self._config = copy.deepcopy(self.default_config)
-        if config is not None:
-            self._config.update(config.items())
 
     @property
     @abc.abstractmethod
@@ -45,19 +48,20 @@ class ImageHostBase(abc.ABC):
         self._cache_dir = directory
 
     @property
-    def config(self):
+    def options(self):
         """
-        User configuration
+        Configuration options provided by the user
 
-        This is a deep copy of :attr:`default_config` that is updated with the
-        `config` argument from initialization.
+        This is the :class:`dict`-like object from the initialization argument
+        of the same name.
         """
-        return self._config
+        return self._options
 
-    @property
-    @abc.abstractmethod
-    def default_config(self):
-        """Default user configuration as a dictionary"""
+    default_config = {}
+    """Default user configuration"""
+
+    argument_definitions = {}
+    """CLI argument definitions (see :attr:`.CommandBase.argument_definitions`)"""
 
     async def upload(self, image_path, cache=True):
         """
@@ -117,14 +121,44 @@ class ImageHostBase(abc.ABC):
             raise RuntimeError(f'Unable to write cache {cache_file}: {msg}')
 
     def _cache_file(self, image_path):
-        # If image is in our cache_directory, the image's file name makes it
-        # unique. This is usually the case when we're uploading screenshots. If
-        # image is not in our cache_directory, use the absolute path as a unique
-        # identifier.
+        # If image_path is in our cache_directory, the image's file name makes
+        # it unique. This is usually the case when we're uploading
+        # screenshots. If image is not in our cache_directory, use the absolute
+        # path as a unique identifier.
         if fs.dirname(image_path) == self.cache_directory:
-            image_path = os.path.basename(image_path)
+            image_path = fs.basename(image_path)
         else:
             image_path = os.path.abspath(image_path)
-        # Max file name length is ususally 255 bytes
+
+        # Make cache file even more unique, e.g. imgbox only has one thumbnail
+        # size per uploaded image, so if we want a different thumbnail size, we
+        # need to upload again.
+        cache_id = self._get_cache_id_as_string()
+        if cache_id:
+            image_path += f'.{cache_id}'
+
+        # Max file name length is usually 255 bytes
         filename = fs.sanitize_filename(image_path[-200:]) + f'.{self.name}.json'
+
         return os.path.join(self.cache_directory, filename)
+
+    def _get_cache_id_as_string(self):
+        def as_str(obj):
+            if isinstance(obj, collections.abc.Mapping):
+                return ','.join(f'{as_str(k)}={as_str(v)}' for k,v in obj.items())
+            elif isinstance(obj, str):
+                return str(obj)
+            elif isinstance(obj, collections.abc.Sequence):
+                return ','.join(as_str(i) for i in obj)
+            else:
+                return str(obj)
+
+        cache_id = self.cache_id
+        if cache_id is None:
+            cache_id = self.options
+        return as_str(cache_id)
+
+    @property
+    def cache_id(self):
+        """Information that makes an upload unique, aside from the file path"""
+        return None
