@@ -5,7 +5,7 @@ subclasses
 
 import re
 
-from .. import release
+from .. import release, signal
 from ..types import ReleaseType
 
 import logging  # isort:skip
@@ -36,12 +36,13 @@ class Query:
     }
 
     def __init__(self, title='', **kwargs):
+        self._kwargs_order = tuple(kwargs)
+        self._signal = signal.Signal()
+        self._signal.add('changed')
         self.title = title
         self.type = kwargs.get('type', self._kwarg_defaults['type'])
         self.year = kwargs.get('year', self._kwarg_defaults['year'])
         self.id = kwargs.get('id', self._kwarg_defaults['id'])
-        self._title_normalized = self._normalize_title(self.title)
-        self._kwargs_order = tuple(kwargs)
 
     @property
     def type(self):
@@ -50,8 +51,13 @@ class Query:
 
     @type.setter
     def type(self, type):
+        before = getattr(self, '_type', None)
+
         self._type = ReleaseType(type)
 
+        if self._type != before:
+            self.signal.emit('changed', self)
+
     @property
     def title(self):
         """Name of the movie or TV series"""
@@ -59,7 +65,13 @@ class Query:
 
     @title.setter
     def title(self, title):
+        before = getattr(self, '_title_normalized', None)
+
         self._title = str(title)
+        self._title_normalized = self._normalize_title(self.title)
+
+        if self._title_normalized != before:
+            self.signal.emit('changed', self)
 
     @property
     def title_normalized(self):
@@ -73,6 +85,8 @@ class Query:
 
     @year.setter
     def year(self, year):
+        before = getattr(self, '_year', None)
+
         if year is None:
             self._year = None
         else:
@@ -86,6 +100,9 @@ class Query:
                 else:
                     self._year = str(year_int)
 
+        if self._year != before:
+            self.signal.emit('changed', self)
+
     @property
     def id(self):
         """Known ID for a specific DB"""
@@ -93,8 +110,29 @@ class Query:
 
     @id.setter
     def id(self, id):
+        before = getattr(self, '_id', None)
+
         self._id = None if id is None else str(id)
 
+        if self._id != before:
+            self.signal.emit('changed', self)
+
+    def update(self, query):
+        """
+        Copy property values from other query
+
+        :param query: :class:`Query` instance to copy values from
+        """
+        before = str(self)
+
+        with self.signal.suspend('changed'):
+            for attr in ('title', 'type', 'year', 'id'):
+                other_value = getattr(query, attr)
+                setattr(self, attr, other_value)
+
+        if str(self) != before:
+            self.signal.emit('changed', self)
+
     _types = {
         ReleaseType.movie: ('movie', 'film'),
         ReleaseType.season: ('season', 'series', 'tv', 'show', 'tvshow'),
@@ -166,6 +204,19 @@ class Query:
             kwargs['type'] = info['type']
         return cls(**kwargs)
 
+    @property
+    def signal(self):
+        """
+        :class:`~.signal.Signal` instance
+
+        Available signals:
+
+        ``changed``
+            Emitted after query parameters changed. Registered callbacks get the
+            instance as a positional argument.
+        """
+        return self._signal
+
     def __eq__(self, other):
         if isinstance(other, type(self)):
             return (
